'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getAssetsByEntry = exports.addAssetHTML = exports.getPublicPath = exports.addChunkDevServer = exports.addChunk = exports.isHotMode = undefined;

var _ramda = require('ramda');

var _ramda2 = _interopRequireDefault(_ramda);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var getPublicPath = function getPublicPath(compilation) {
  var options = compilation.options;
  var devServer = options.devServer;

  if (devServer && devServer.publicPath) return devServer.publicPath;

  var output = options.output;

  if (output && output.publicPath) return output.publicPath;

  // TODO seems like a non-standard place to look.
  var publicPath = options.publicPath;

  if (publicPath) return publicPath;

  return '/';
};

var isHotMode = function isHotMode(c) {
  return c.options.devServer && c.options.devServer.hot;
};

var addChunk = _ramda2.default.curry(function (type, chunk, entry) {
  /* The chunk _type_ may be new to this entry. */
  Object.assign(entry, _defineProperty({}, type, entry[type] || []));
  entry[type].push(chunk);
  return entry;
});

var addChunkDevServer = addChunk('js', '/webpack-dev-server.js');

var addAssetHTML = function addAssetHTML(buildAssets, fileName, _source) {
  return Object.assign(buildAssets, _defineProperty({}, fileName, {
    source: function source() {
      return _source;
    },
    size: function size() {
      return _source.length;
    }
  }));
};

var parseFileType = _ramda2.default.compose(
/* nth(1) because match returns the whole matching regex as index 0
with matching groups as added indexes thereafter. */
_ramda2.default.nth(1),
/* Reference for pattern: http://regexr.com/3aomt */
_ramda2.default.match(/\.([^.?]+)(?:\?.*)*$/));

var notSourceMapFile = _ramda2.default.compose(_ramda2.default.isEmpty, _ramda2.default.match(/\.map$/));

/* TODO: This pipeline is brittle. It will throw an error if any given
asset is not a valid file name; specifically any string without an
extension will break this pipeline. To fix this we should use a Maybe
Type to branch on the match logic. */

//    getAssetsByEntry :: String -> String -> EntryChunks -> EntryAssets
var getAssetsByEntry = _ramda2.default.curry(function (publicPath, hash) {
  return _ramda2.default.compose(_ramda2.default.groupBy(parseFileType), _ramda2.default.map(function (fileName) {
    return '' + publicPath + fileName + '?' + hash;
  }), _ramda2.default.filter(notSourceMapFile));
});

exports.default = {
  getPublicPath: getPublicPath,
  isHotMode: isHotMode,
  addChunk: addChunk,
  addChunkDevServer: addChunkDevServer,
  addAssetHTML: addAssetHTML,
  getAssetsByEntry: getAssetsByEntry
};
exports.isHotMode = isHotMode;
exports.addChunk = addChunk;
exports.addChunkDevServer = addChunkDevServer;
exports.getPublicPath = getPublicPath;
exports.addAssetHTML = addAssetHTML;
exports.getAssetsByEntry = getAssetsByEntry;